
## quicksong

This is a very basic program for detecting birdsong in long recordings that may be contaminated with cage noise. It uses the same general principle employed widely in the birdsong community, but instead of having to manually tweak thresholds, a support vector machine classifier is trained using manually labeled data.

This is a work in progress and should be installed from source in a dedicated virtual environment. Use the `script` option when installing to get the dependencies for the song-detect script

``` shell
python3 -m venv venv
venv/bin/python -m pip install --upgrade pip setuptools wheel
venv/bin/python -m pip install -e .[script]
```



